##########
multistage
##########
|License| |Issues| |Pypi|

|Docs| |UnitTests|

``multistage`` is a library for multistage neural networks.

Installation
============

``multistage`` is installable with ``pip``:

.. code-block:: sh

    pip install multistage

or from GitHub:

.. code-block:: sh

    git clone https://github.com/unalmis/multistage.git
    cd multistage
    pip install --editable .

You may optionally install the developer requirements if you want to run tests.

.. code-block:: sh

    pip install -r requirements-dev.txt


For full details of various options see the `API documentation <https://unalmis.github.io/multistage/>`__.


.. |License| image:: https://img.shields.io/github/license/unalmis/multistage?color=blue&logo=open-source-initiative&logoColor=white
    :target: https://github.com/unalmis/multistage/blob/main/LICENSE
    :alt: License

.. |Docs| image:: https://github.com/unalmis/multistage/actions/workflows/docs.yml/badge.svg
    :target: https://unalmis.github.io/multistage/
    :alt: Documentation

.. |UnitTests| image:: https://github.com/unalmis/multistage/actions/workflows/unittest.yml/badge.svg
    :target: https://github.com/unalmis/multistage/actions/workflows/unittest.yml
    :alt: UnitTests

.. |Issues| image:: https://img.shields.io/github/issues/unalmis/multistage
    :target: https://github.com/unalmis/multistage/issues
    :alt: GitHub issues

.. |Pypi| image:: https://img.shields.io/pypi/v/multistage
    :target: https://pypi.org/project/multistage/
    :alt: Pypi
